precision mediump float;

varying highp vec2 textureCoordinate;

uniform sampler2D inputImageTexture;
uniform float centerX;
uniform float centerY;
uniform float radius;
uniform float k;
uniform int xMutiplier;
uniform int yMutiplier;

const float FadeLength = 0.23;

const int GAUSSIAN_SAMPLES = 9;

highp vec2 blurCoordinates[GAUSSIAN_SAMPLES];

void main() {
	 
	highp vec2 singleStepOffset = vec2(0.002 * float(xMutiplier), 0.002 * float(yMutiplier));
	
	float off = abs(-k * centerX + (1.0 - centerY) + k * textureCoordinate.x - textureCoordinate.y)/sqrt(k * k + 1.0);
	
	float blurRate = smoothstep(radius, radius + FadeLength, off);
	
	highp vec2 blurStep;
	
	blurStep = (-4.0) * singleStepOffset * blurRate;
 	blurCoordinates[0] = textureCoordinate.xy + blurStep;
	blurStep = (-3.0) * singleStepOffset * blurRate;
 	blurCoordinates[1] = textureCoordinate.xy + blurStep;
	blurStep = (-2.0) * singleStepOffset * blurRate;
 	blurCoordinates[2] = textureCoordinate.xy + blurStep;
	blurStep = (-1.0) * singleStepOffset * blurRate;
 	blurCoordinates[3] = textureCoordinate.xy + blurStep;

 	blurCoordinates[4] = textureCoordinate.xy;
 	blurStep = (1.0) * singleStepOffset * blurRate;
 	blurCoordinates[5] = textureCoordinate.xy + blurStep;
	blurStep = (2.0) * singleStepOffset * blurRate;
 	blurCoordinates[6] = textureCoordinate.xy + blurStep;
	blurStep = (3.0) * singleStepOffset * blurRate;
 	blurCoordinates[7] = textureCoordinate.xy + blurStep;
	blurStep = (4.0) * singleStepOffset * blurRate;
 	blurCoordinates[8] = textureCoordinate.xy + blurStep;
 	
    gl_FragColor = texture2D(inputImageTexture, blurCoordinates[0]) * 0.05;
    gl_FragColor += texture2D(inputImageTexture, blurCoordinates[1]) * 0.09;
    gl_FragColor += texture2D(inputImageTexture, blurCoordinates[2]) * 0.12;
    gl_FragColor += texture2D(inputImageTexture, blurCoordinates[3]) * 0.15;
    gl_FragColor += texture2D(inputImageTexture, blurCoordinates[4]) * 0.18;
    gl_FragColor += texture2D(inputImageTexture, blurCoordinates[5]) * 0.15;
    gl_FragColor += texture2D(inputImageTexture, blurCoordinates[6]) * 0.12;
    gl_FragColor += texture2D(inputImageTexture, blurCoordinates[7]) * 0.09;
    gl_FragColor += texture2D(inputImageTexture, blurCoordinates[8]) * 0.05;
}