precision mediump float;

varying highp vec2 textureCoordinate;

uniform sampler2D inputImageTexture;
uniform float centerX;
uniform float centerY;
uniform float radius;
uniform float k;
uniform float visibility;

const float FadeLength = 0.06;
const vec4 blurIndicator = vec4(0.9, 0.9, 0.9, 1.0);
const float blurIndicatorMixFactor = 0.72;


void main() {
	
	float off = abs(-k * centerX + (1.0 - centerY) + k * textureCoordinate.x - textureCoordinate.y) / sqrt(k * k + 1.0);
	
	lowp float blurRate = smoothstep(radius, radius + FadeLength, off);
	
	lowp float mix =  blurRate * blurIndicatorMixFactor * visibility;
	
	gl_FragColor = texture2D(inputImageTexture, textureCoordinate);
	
	if(mix > 0.0){
		//Nexus 10 & Nexus 4 error
		//gl_FragColor = mix(gl_FragColor, blurIndicator, mix);
		gl_FragColor = gl_FragColor * (1.0 - mix) + blurIndicator * mix;
	}
	
}